import React from "react"

import Carousel, { consts } from "react-elastic-carousel"
import IconButton from "@mui/material/IconButton"
import ChevronLeftIcon from "@mui/icons-material/ChevronLeft"
import ChevronRightIcon from "@mui/icons-material/ChevronRight"
import { makeStyles } from "@material-ui/core"

import { ClientImage } from "../assets/styles/styled"
import "../assets/styles/css/carousel.css"
import { Typography } from "@mui/material"
import myTheme from "../assets/styles/myTheme"

const myPalette = myTheme.palette

const clientsSrc = [
  "ads.png",
  "GE.jpg",
  "hr.svg",
  "inoac.png",
  "ragasa.svg",
  "RQ.png",
  "slide03.png",
  "slide04.png",
  "tupy.png",
  "VDE.png",
  "viba.png"
]

const breakPoints = [
  { width: 1, itemsToShow: 1 },
  { width: 550, itemsToShow: 2, itemsToScroll: 2 },
  { width: 850, itemsToShow: 3, itemsToScroll: 3 },
  { width: 1150, itemsToShow: 4, itemsToScroll: 2 },
  { width: 1450, itemsToShow: 5, itemsToScroll: 2 },
  { width: 1750, itemsToShow: 6, itemsToScroll: 2 },
]

const useStyles = makeStyles((theme) => ({
  container: {
    padding: "20px 20px",
    margin: "20px 20px"
  },
  highlighter: {
    color: myPalette.primary.main
  }
}))

function ClientCarousel() {
  const classes = useStyles()
  
  function myArrow({ type, onClick, isEdge }) {
    const pointer = type === consts.PREV ? (
      <ChevronLeftIcon />
    ) : (
      <ChevronRightIcon />
    )
    return (
      <IconButton onClick={onClick} disabled={isEdge}>
        {pointer}
      </IconButton>
    )
  }

  return (
    <div className={classes.container}>
      <Typography id="carousel-title" variant="h5" component="h1" align="center" sx={{ mb: 3, color: "#404040" }}>
        Ellos confían en <span className={classes.highlighter}>nosotros</span>
      </Typography>
      <Carousel 
        breakPoints={breakPoints}
        enableAutoPlay
        autoPlaySpeed={3000}
        itemPadding={[10, 50]}
        renderArrow={myArrow}
      >
        {
          clientsSrc.map((src, index) => {
            return (
              <ClientImage key={index} src={`${process.env.PUBLIC_URL}/assets/clients/${src}`} />
            )
          })
        }
      </Carousel>
    </div>
  )
}

export default ClientCarousel
